pub struct MidHandshakeSslStream<S> { /* fields omitted */ }
An SSL stream midway through the handshake process.
Returns a shared reference to the inner stream.
Returns a mutable reference to the inner stream.
Returns a shared reference to the Ssl of the stream.
Returns the underlying error which interrupted this handshake.
Consumes self, returning its error.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.