Struct openssl::ssl::SslSessionRef [−][src]
pub struct SslSessionRef(_);Expand description
Reference to SslSession.
Implementations
Returns the SSL session ID.
This corresponds to SSL_SESSION_get_id.
Returns the length of the master key.
This corresponds to SSL_SESSION_get_master_key.
Copies the master key into the provided buffer.
Returns the number of bytes written, or the size of the master key if the buffer is empty.
This corresponds to SSL_SESSION_get_master_key.
Gets the maximum amount of early data that can be sent on this session.
Requires OpenSSL 1.1.1 or newer.
This corresponds to SSL_SESSION_get_max_early_data.
Returns the time at which the session was established, in seconds since the Unix epoch.
This corresponds to SSL_SESSION_get_time.
Returns the sessions timeout, in seconds.
A session older than this time should not be used for session resumption.
This corresponds to SSL_SESSION_get_timeout.
Returns the session’s TLS protocol version.
Requires OpenSSL 1.1.0 or newer.
This corresponds to SSL_SESSION_get_protocol_version.
Serializes the session into a DER-encoded structure.
This corresponds to i2d_SSL_SESSION.